@@ -133,10 +133,6 @@ GREMLIN_OPTIONS = [
     '.T.label',
     '.T.key',
     '.T.value',
-    '.incr',
-    '.Order.incr',
-    '.decr',
-    '.Order.decr',
     '.asc',
     '.Order.asc',
     '.desc',
